/**
 * Checks if the given input is null, undefined, empty, or only contains whitespace.
 *
 * - If the input is a string, it checks if it's empty or only contains whitespace.
 * - If the input is an array, it checks if it's empty.
 * - If the input is an object, it checks if it has any own enumerable properties.
 * - If the input is a Set or a Map, it checks if it's empty.
 *
 * @param {any} input - The value to check.
 * @returns {boolean} - Returns `true` if the input is null, undefined, empty, or only contains whitespace. Otherwise, it returns `false`.
 */
export function NullEmptyOrWhitespace(input) {
    if (input === null)
        return true;
    if (input === undefined)
        return true;
    if (typeof input === "string")
        return input.trim() === "";
    if (Array.isArray(input))
        return input.length === 0;
    if (input instanceof Set || input instanceof Map)
        return input.size === 0;
    if (typeof input === "object")
        return Object.getOwnPropertyNames(input).length === 0;
    return false;
}
